@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20250528';
+our $VERSION = '5.20250720';
 our %utilities;
 
 sub utilities {
@@ -2147,6 +2147,27 @@ my %delta = (
         removed => {
         }
     },
+    5.042000 => {
+        delta_from => 5.041013,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.043000 => {
+        delta_from => 5.042000,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.043001 => {
+        delta_from => 5.043,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
